==> it%2B%2B3.8.0.tar.gz: it++3.8.0/src/comm/pulse_shape.cpp <==
/*---------------------------------------------------------------------------*
 *                                   IT++			             *
 *---------------------------------------------------------------------------*
 * Copyright (c) 1995-2003 by Tony Ottosson, Thomas Eriksson, Pl Frenger,   *
 * Tobias Ringstrm, and Jonas Samuelsson.                                   *
 *                                                                           *
 * Permission to use, copy, modify, and distribute this software and its     *
 * documentation under the terms of the GNU General Public License is hereby *
 * granted. No representations are made about the suitability of this        *
 * software for any purpose. It is provided "as is" without expressed or     *
 * implied warranty. See the GNU General Public License for more details.    *
 *---------------------------------------------------------------------------*/

/*! 
  \file 
  \brief Implementations of puls shaping classes.
  \author Tony Ottosson and Hkan Eriksson

  1.9

  2004/09/05 03:33:23
*/

#include "comm/pulse_shape.h"

namespace itpp {

  //--------------------------------------------------------------------------------------
  // Template instantiations
  //--------------------------------------------------------------------------------------

  //! Template instantiation of \c double, \c double and \c double of Pulse_Shape<T1,T2,T3>
  template class Pulse_Shape<double,double,double>;
  //! Template instantiation of \c complex<double>, \c double and \c complex<double> of Pulse_Shape<T1,T2,T3>
  template class Pulse_Shape<complex<double>, double, complex<double> >;
  //! Template instantiation of \c complex<double>, \c complex<double> an \c complex<double> of Pulse_Shape<T1,T2,T3>
  template class Pulse_Shape<complex<double>, complex<double>, complex<double> >;

  //! Template instantiation of \c double of Root_Raised_Cosine<T1>
  template class Root_Raised_Cosine<double>;
  //! Template instantiation of \c complex<double> of Root_Raised_Cosine<T1>
  template class Root_Raised_Cosine<complex<double> >;

  //! Template instantiation of \c double of Raised_Cosine<T1>
  template class Raised_Cosine<double>;
  //! Template instantiation of \c complex<double> of Raised_Cosine<T1>
  template class Raised_Cosine<complex<double> >;
  
} //namespace itpp

==> it%2B%2B3.8.1.tar.gz: it++3.8.1/src/comm/pulse_shape.cpp <==
/*---------------------------------------------------------------------------*
 *                                   IT++			             *
 *---------------------------------------------------------------------------*
 * Copyright (c) 1995-2005 by Tony Ottosson, Thomas Eriksson, Pl Frenger,   *
 * Tobias Ringstrm, and Jonas Samuelsson.                                   *
 *                                                                           *
 * Permission to use, copy, modify, and distribute this software and its     *
 * documentation under the terms of the GNU General Public License is hereby *
 * granted. No representations are made about the suitability of this        *
 * software for any purpose. It is provided "as is" without expressed or     *
 * implied warranty. See the GNU General Public License for more details.    *
 *---------------------------------------------------------------------------*/

/*! 
  \file 
  \brief Implementations of puls shaping classes.
  \author Tony Ottosson, Hkan Eriksson and Adam Piatyszek

  1.12

  2005/06/13 08:37:21
*/

#include "comm/pulse_shape.h"

namespace itpp {

  //---------------------------------------------------------------------------
  // Template instantiations
  //---------------------------------------------------------------------------

  template class Pulse_Shape<double, double, double>;
  template class Pulse_Shape<std::complex<double>, double, std::complex<double> >;
  template class Pulse_Shape<std::complex<double>, std::complex<double>, std::complex<double> >;

  template class Root_Raised_Cosine<double>;
  template class Root_Raised_Cosine<std::complex<double> >;

  template class Raised_Cosine<double>;
  template class Raised_Cosine<std::complex<double> >;
  
} //namespace itpp
